/* Automatically generated file, do not edit */
static const el_func_t el_func[] = {
    ed_argument_digit,         ed_clear_screen,           
    ed_command,                ed_delete_next_char,       
    ed_delete_prev_char,       ed_delete_prev_word,       
    ed_digit,                  ed_end_of_file,            
    ed_ignore,                 ed_insert,                 
    ed_kill_line,              ed_move_to_beg,            
    ed_move_to_end,            ed_newline,                
    ed_next_char,              ed_next_history,           
    ed_next_line,              ed_prev_char,              
    ed_prev_history,           ed_prev_line,              
    ed_prev_word,              ed_quoted_insert,          
    ed_redisplay,              ed_search_next_history,    
    ed_search_prev_history,    ed_sequence_lead_in,       
    ed_start_over,             ed_transpose_chars,        
    ed_unassigned,             em_capitol_case,           
    em_copy_prev_word,         em_copy_region,            
    em_delete_next_word,       em_delete_or_list,         
    em_delete_prev_char,       em_exchange_mark,          
    em_gosmacs_transpose,      em_inc_search_next,        
    em_inc_search_prev,        em_kill_line,              
    em_kill_region,            em_lower_case,             
    em_meta_next,              em_next_word,              
    em_set_mark,               em_toggle_overwrite,       
    em_universal_argument,     em_upper_case,             
    em_yank,                   vi_add,                    
    vi_add_at_eol,             vi_alias,                  
    vi_change_case,            vi_change_meta,            
    vi_change_to_eol,          vi_command_mode,           
    vi_comment_out,            vi_delete_meta,            
    vi_delete_prev_char,       vi_end_big_word,           
    vi_end_word,               vi_histedit,               
    vi_history_word,           vi_insert,                 
    vi_insert_at_bol,          vi_kill_line_prev,         
    vi_list_or_eof,            vi_match,                  
    vi_next_big_word,          vi_next_char,              
    vi_next_word,              vi_paste_next,             
    vi_paste_prev,             vi_prev_big_word,          
    vi_prev_char,              vi_prev_word,              
    vi_redo,                   vi_repeat_next_char,       
    vi_repeat_prev_char,       vi_repeat_search_next,     
    vi_repeat_search_prev,     vi_replace_char,           
    vi_replace_mode,           vi_search_next,            
    vi_search_prev,            vi_substitute_char,        
    vi_substitute_line,        vi_to_column,              
    vi_to_history_line,        vi_to_next_char,           
    vi_to_prev_char,           vi_undo,                   
    vi_undo_line,              vi_yank,                   
    vi_yank_end,               vi_zero,                   
};
